@@ -3,7 +3,9 @@ from __future__ import annotations
 import os
 import logging
 from pathlib import Path
-from typing import cast, Type, TYPE_CHECKING, Any
+from typing import cast, Type, TYPE_CHECKING, Any, Literal
+
+from typing_extensions import TypeAlias  # noqa[TC002]
 
 from checkov.bicep.graph_builder.context_definitions import build_definitions_context
 from checkov.bicep.checks.param.registry import registry as param_registry
@@ -25,7 +27,7 @@ from checkov.common.output.graph_record import GraphRecord
 from checkov.common.output.record import Record
 from checkov.common.output.report import Report
 from checkov.common.bridgecrew.check_type import CheckType
-from checkov.common.runners.base_runner import BaseRunner, CHECKOV_CREATE_GRAPH
+from checkov.common.runners.base_runner import BaseRunner
 from checkov.common.typing import _CheckResult
 from checkov.common.util.secrets import omit_secret_value_from_checks
 from checkov.common.util.suppression import collect_suppressions_for_report
@@ -38,10 +40,12 @@ if TYPE_CHECKING:
     from checkov.common.images.image_referencer import Image
     from networkx import DiGraph
     from pycep.typing import BicepJson
-    from typing_extensions import Literal
+
+_BicepContext: TypeAlias = "dict[str, dict[str, Any]]"
+_BicepDefinitions: TypeAlias = "dict[Path, BicepJson]"
 
 
-class Runner(ImageReferencerMixin[None], BaseRunner[BicepGraphManager]):
+class Runner(ImageReferencerMixin[None], BaseRunner[_BicepDefinitions, _BicepContext, BicepGraphManager]):
     check_type = CheckType.BICEP  # noqa: CCE003  # a static attribute
 
     block_type_registries: 'dict[Literal["parameters", "resources"], BaseCheckRegistry]' = {  # noqa: CCE003  # a static attribute
@@ -66,8 +70,8 @@ class Runner(ImageReferencerMixin[None], BaseRunner[BicepGraphManager]):
         )
         self.graph_registry: Registry = get_graph_checks_registry(self.check_type)
 
-        self.context: dict[str, dict[str, Any]] = {}
-        self.definitions: dict[Path, BicepJson] = {}  # type:ignore[assignment]  # need to check, how to support subclass differences
+        self.context: _BicepContext = {}
+        self.definitions: _BicepDefinitions = {}
         self.definitions_raw: dict[Path, list[tuple[int, str]]] = {}    # type:ignore[assignment]
         self.root_folder: str | Path | None = None
 
@@ -101,21 +105,18 @@ class Runner(ImageReferencerMixin[None], BaseRunner[BicepGraphManager]):
             if external_checks_dir:
                 for directory in external_checks_dir:
                     resource_registry.load_external_checks(directory)
-
-                    if CHECKOV_CREATE_GRAPH:
-                        self.graph_registry.load_external_checks(directory)
+                    self.graph_registry.load_external_checks(directory)
 
             self.context = build_definitions_context(definitions=self.definitions, definitions_raw=self.definitions_raw)
 
-            if CHECKOV_CREATE_GRAPH:
-                logging.info("Creating Bicep graph")
-                local_graph = self.graph_manager.build_graph_from_definitions(self.definitions)
-                logging.info("Successfully created Bicep graph")
+            logging.info("Creating Bicep graph")
+            local_graph = self.graph_manager.build_graph_from_definitions(self.definitions)
+            logging.info("Successfully created Bicep graph")
 
-                self.graph_manager.save_graph(local_graph)
-                self.definitions, self.breadcrumbs = convert_graph_vertices_to_tf_definitions(
-                    vertices=local_graph.vertices, root_folder=root_folder
-                )
+            self.graph_manager.save_graph(local_graph)
+            self.definitions, self.breadcrumbs = convert_graph_vertices_to_tf_definitions(
+                vertices=local_graph.vertices, root_folder=root_folder
+            )
 
         self.pbar.initiate(len(self.definitions))
 
@@ -123,8 +124,7 @@ class Runner(ImageReferencerMixin[None], BaseRunner[BicepGraphManager]):
         self.add_python_check_results(report=report, runner_filter=runner_filter, root_folder=root_folder)
 
         # run graph checks
-        if CHECKOV_CREATE_GRAPH:
-            self.add_graph_check_results(report=report, runner_filter=runner_filter)
+        self.add_graph_check_results(report=report, runner_filter=runner_filter)
 
         if runner_filter.run_image_referencer:
             if files:
