@@ -5,7 +5,7 @@ from checkov.common.models.enums import CheckCategories
 class S3BlockPublicACLs(BaseResourceValueCheck):
 
     def __init__(self):
-        name = "Ensure S3 bucket has block public ACLS enabled"
+        name = "Ensure S3 bucket has block public ACLs enabled"
         id = "CKV_AWS_53"
         supported_resources = ['AWS::S3::Bucket']
         categories = [CheckCategories.GENERAL_SECURITY]
