@@ -9,7 +9,7 @@ from checkov.dockerfile.base_dockerfile_check import BaseDockerfileCheck
 if TYPE_CHECKING:
     from dockerfile_parse.parser import _Instruction
 
-MULTI_STAGE_PATTERN = re.compile(r"(\S+)\s+as\s+(\S+)", re.IGNORECASE)
+MULTI_STAGE_PATTERN = re.compile(r"(?:--platform=\S+\s+)?(\S+)\s+as\s+(\S+)", re.IGNORECASE)
 
 
 class ReferenceLatestTag(BaseDockerfileCheck):
@@ -25,16 +25,18 @@ class ReferenceLatestTag(BaseDockerfileCheck):
 
         for content in conf:
             base_image = content["value"]
-            multi_stage = re.match(MULTI_STAGE_PATTERN, base_image)
-            if multi_stage:
-                base_image = multi_stage[1]
-                stages.append(multi_stage[2])
+            if " as " in base_image.lower():
+                # do an initial lookup before using the regex
+                multi_stage = re.match(MULTI_STAGE_PATTERN, base_image)
+                if multi_stage:
+                    base_image = multi_stage[1]
+                    stages.append(multi_stage[2])
 
             if ":" not in base_image and base_image not in stages and base_image != "scratch":
                 return CheckResult.FAILED, [content]
             elif base_image.endswith(":latest"):
                 return CheckResult.FAILED, [content]
-        return CheckResult.PASSED, None
+        return CheckResult.PASSED, [content]
 
 
 check = ReferenceLatestTag()
