@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Any
+from typing import Any, List
 
 from checkov.common.models.enums import CheckResult, CheckCategories
 from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
@@ -24,5 +24,8 @@ class LBTargetGroupDefinesHealthCheck(BaseResourceCheck):
             return CheckResult.FAILED
         return CheckResult.UNKNOWN
 
+    def get_evaluated_keys(self) -> List[str]:
+        return ["protocol", "health_check"]
+
 
 check = LBTargetGroupDefinesHealthCheck()
